---
title: 토스페이먼츠 해외결제 서비스 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: 토스페이먼츠 해외결제 서비스 이용안내
  description: >-
    토스페이먼츠의 해외카드결제 서비스를 통한 해외결제 이용방법 안내드립니다. 토스페이먼츠의 지원결제 수단 및 서비스 특징, 입점기준,
    토스페이먼츠 MID추가 절차, 참고사항까지 자세한 정보를 확인해보세요.
  keywords:
    - 해외결제
tags:
  - 토스페이먼츠
  - 해외결제
pgCompanies:
  - 토스페이먼츠
searchTags:
  - 해외카드 특약
  - 해외카드
  - 토스페이먼츠 해외결제
  - 해외결제
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="토스페이먼츠를 통한 해외결제 이용방법 안내드립니다." />

#### **토스페이먼츠의 해외카드결제 서비스 이용안내**

1. **지원 결제수단**

- 해외카드 (VISA, MASTER, JCB)

##### **2. 지원 서비스 특징**

- 지원가능 통화 : KRW (승인/정산)
- 결제방식 : 토스페이먼츠 결제창을 띄우는 방식으로만 가능
- 지원가능언어 : 한국어, 영어, 중국어
- 정산방식 : 원화정산

##### **3. 입점기준**

- 국내사업자로만 계약이 가능합니다. (해외 법인 사업자 계약불가)
- 토스페이먼츠를 통해 해외카드 사용 특약을 맺은 후 서비스 사용이 가능합니다.
- 컨텐츠 상품도 입점심사을 받아볼 수 있습니다.

##### **4. 참고사항**

- 토스페이먼츠의 경우에는 해외카드 결제 시 국내 카드 결제와 비슷하게 인증시스템(3D인증)을 거쳐야하기에 인증 절차가 없는 해외 결제자들에게는 결제를 하는데 불편함이 있습니다.

##### **5. 신청방법**

기존에 토스페이먼츠를 통해 국내결제만 이용하고 계셨다면 해외결제용 MID 추가발급이 필요합니다.\
신규계약절차와 동일한 접수 프로세스로 진행 해주시기 바랍니다.

<Callout title="토스페이먼츠 상점아이디 추가절차 보러가기 ↗" icon="" />
